==> myfaces-tobago-5.6.0-source-release.zip: tobago-5.6.0/tobago-theme/tobago-theme-standard/src/main/ts/tobago-css.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export enum Css {
  ACTIVE = "active",
  AUTOCOMPLETE = "autocomplete",
  AUTOCOMPLETE_INPUT = "autocomplete-input",
  COLLAPSE = "collapse",
  COLLAPSING = "collapsing",
  D_NONE = "d-none",
  DISABLED = "disabled",
  DROPDOWN_MENU = "dropdown-menu",
  FIXED_BOTTOM = "fixed-bottom",
  INPUT_GROUP = "input-group",
  POSITION_RELATIVE = "position-relative",
  SHOW = "show",
  TABLE_ACTIVE = "table-active",
  TABLE_INFO = "table-info",
  TABLE_PRIMARY = "table-primary",
  TOBAGO_COLLAPSED = "tobago-collapsed",
  TOBAGO_DISABLED = "tobago-disabled",
  TOBAGO_DROP_ZONE = "tobago-drop-zone",
  TOBAGO_DROPDOWN_SUBMENU = "tobago-dropdown-submenu",
  TOBAGO_EXPANDED = "tobago-expanded",
  TOBAGO_FOCUS = "tobago-focus",
  TOBAGO_NO_ENTRIES = "tobago-no-entries",
  TOBAGO_OPTIONS = "tobago-options",
  TOBAGO_PLACEHOLDER = "tobago-placeholder",
  TOBAGO_PRESELECT = "tobago-preselect",
  TOBAGO_SELECTED = "tobago-selected",
  TOBAGO_SPLITLAYOUT_HORIZONTAL = "tobago-splitLayout-horizontal",
  TRASH = "trash"
}

==> myfaces-tobago-5.7.2-source-release.zip: tobago-5.7.2/tobago-theme/tobago-theme-standard/src/main/ts/tobago-css.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export enum Css {
  ACTIVE = "active",
  AUTOCOMPLETE = "autocomplete",
  AUTOCOMPLETE_INPUT = "autocomplete-input",
  COLLAPSE = "collapse",
  COLLAPSING = "collapsing",
  D_NONE = "d-none",
  DISABLED = "disabled",
  DROPDOWN = "dropdown",
  DROPDOWN_ITEM = "dropdown-item",
  DROPDOWN_MENU = "dropdown-menu",
  DROPDOWN_MENU_END = "dropdown-menu-end",
  FIXED_BOTTOM = "fixed-bottom",
  INPUT_GROUP = "input-group",
  POSITION_RELATIVE = "position-relative",
  SHOW = "show",
  TABLE_ACTIVE = "table-active",
  TABLE_INFO = "table-info",
  TABLE_PRIMARY = "table-primary",
  TOBAGO_COLLAPSED = "tobago-collapsed",
  TOBAGO_DISABLED = "tobago-disabled",
  TOBAGO_DROP_ZONE = "tobago-drop-zone",
  TOBAGO_DROPDOWN_MENU = "tobago-dropdown-menu",
  TOBAGO_DROPDOWN_SUBMENU = "tobago-dropdown-submenu",
  TOBAGO_EXPANDED = "tobago-expanded",
  TOBAGO_FOCUS = "tobago-focus",
  TOBAGO_NO_ENTRIES = "tobago-no-entries",
  TOBAGO_OPTIONS = "tobago-options",
  TOBAGO_PLACEHOLDER = "tobago-placeholder",
  TOBAGO_PRESELECT = "tobago-preselect",
  TOBAGO_SELECTED = "tobago-selected",
  TOBAGO_SHOW = "tobago-show",
  TOBAGO_SPLITLAYOUT_HORIZONTAL = "tobago-splitLayout-horizontal",
  TRASH = "trash"
}
